@@ -1,18 +1,17 @@
 /*
  * e-mail-identity-combo-box.c
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) version 3.
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+ * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -260,8 +259,7 @@ mail_identity_combo_box_constructed (GObject *object)
 	GtkCellRenderer *cell_renderer;
 
 	/* Chain up to parent's constructed() method. */
-	G_OBJECT_CLASS (e_mail_identity_combo_box_parent_class)->
-		constructed (object);
+	G_OBJECT_CLASS (e_mail_identity_combo_box_parent_class)->constructed (object);
 
 	combo_box = GTK_COMBO_BOX (object);
 	cell_layout = GTK_CELL_LAYOUT (object);
