@@ -508,8 +508,7 @@ mail_config_defaults_page_constructed (GObject *object)
 	page = E_MAIL_CONFIG_DEFAULTS_PAGE (object);
 
 	/* Chain up to parent's constructed() method. */
-	G_OBJECT_CLASS (e_mail_config_defaults_page_parent_class)->
-		constructed (object);
+	G_OBJECT_CLASS (e_mail_config_defaults_page_parent_class)->constructed (object);
 
 	source = e_mail_config_defaults_page_get_account_source (page);
 	extension_name = E_SOURCE_EXTENSION_MAIL_ACCOUNT;
@@ -573,7 +572,7 @@ mail_config_defaults_page_constructed (GObject *object)
 	page->priv->drafts_button = widget;  /* not referenced */
 	gtk_widget_show (widget);
 
-	g_object_bind_property (
+	e_binding_bind_object_text_property (
 		composition_ext, "drafts-folder",
 		widget, "folder-uri",
 		G_BINDING_BIDIRECTIONAL |
@@ -602,7 +601,7 @@ mail_config_defaults_page_constructed (GObject *object)
 		gtk_widget_set_sensitive (widget, FALSE);
 	}
 
-	g_object_bind_property (
+	e_binding_bind_object_text_property (
 		submission_ext, "sent-folder",
 		widget, "folder-uri",
 		G_BINDING_BIDIRECTIONAL |
