@@ -515,6 +515,11 @@ mail_paned_view_set_folder (EMailReader *reader,
 
 	view = E_MAIL_VIEW (reader);
 	shell_view = e_mail_view_get_shell_view (view);
+
+	/* Can be NULL, if the shell window was closed meanwhile */
+	if (!shell_view)
+		return;
+
 	shell_window = e_shell_view_get_shell_window (shell_view);
 
 	shell = e_shell_window_get_shell (shell_window);
@@ -1054,7 +1059,7 @@ e_mail_paned_view_init (EMailPanedView *view)
 {
 	view->priv = E_MAIL_PANED_VIEW_GET_PRIVATE (view);
 
-	g_signal_connect (
+	e_signal_connect_notify (
 		view, "notify::group-by-threads",
 		G_CALLBACK (mail_paned_view_notify_group_by_threads_cb),
 		NULL);
